import grpc
from spidr4 import rpc
import example_config as e
import time

if __name__ == '__main__':
    # Connect to the spidr4 control
    with grpc.insecure_channel(e.spidr4host()) as channel:

        # Get the control service
        trigger = rpc.TriggerStub(channel)

        # Enable the trigger logic block
        trigger.Enable(rpc.EMPTY)

        # Just in case it was still running
        trigger.StopAutoShutter(rpc.EMPTY)

        # Configure the trigger using the internal auto-shutter
        trigCfg = rpc.TriggerConfig(
            # Shutter mode auto-generate, start on software
            shutter_input = rpc.SHUTTER_IN_AUTO_GEN,
            # T0 sync also by software
            t0_input = rpc.T0SYNC_IN_SOFTWARE,
            # Show shutter signaal on busy-out
            busy_output = rpc.BUSY_OUT_SHUTTER,
            # Open shutter for 250 us
            auto_shutter_open_us = 250,
            # Close shutter for 750 us
            auto_shutter_close_us = 750,
            # Generate 2000 shutters
            shutter_count = 2000
        )
        trigger.SetConfig(trigCfg)

        # Reset all counters
        trigger.ResetShutterCounter(rpc.EMPTY)
        trigger.ResetT0Counter(rpc.EMPTY)

        # Print auto-shutter
        trigger.StartAutoShutter(rpc.EMPTY)

        # Wait until it is done
        status = trigger.GetStatus(rpc.EMPTY)
        while status.auto_shutter_busy:
            time.sleep(0.1)
            # Generate a pointless t0 sync, just for the fun of it.
            trigger.T0Sync(rpc.EMPTY)

            # Get the current status
            status = trigger.GetStatus(rpc.EMPTY)
            print(f"Shutter count: {status.shutter_counter}")
            print(f"T0-sync count: {status.t0sync_counter} (should be ~1/100th of shutter_counter)")